.. currentmodule:: celery.datastructures

.. automodule:: celery.datastructures

    .. contents::
        :local:

    AttributeDict
    -------------

    .. autoclass:: AttributeDict
        :members:

    .. autoclass:: AttributeDictMixin
        :members:

    DictAttribute
    -------------

    .. autoclass:: DictAttribute
        :members:
        :undoc-members:

    ConfigurationView
    -----------------

    .. autoclass:: ConfigurationView
        :members:
        :undoc-members:

    ExceptionInfo
    -------------

    .. autoclass:: ExceptionInfo
        :members:

    LimitedSet
    ----------

    .. autoclass:: LimitedSet
        :members:
        :undoc-members:

    LRUCache
    --------

    .. autoclass:: LRUCache
        :members:
        :undoc-members:
